@@ -3,12 +3,12 @@ package Acme::CPANModules::XSVersions;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-03-18'; # DATE
+our $DATE = '2023-09-05'; # DATE
 our $DIST = 'Acme-CPANModules-XSVersions'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $LIST = {
-    summary => 'List of XS versions of Perl modules',
+    summary => 'List of Perl modules which have XS implementation or backend',
     description => <<'_',
 
 This list catalogs (pure-) Perl modules that have their XS counterparts ("fast
@@ -55,7 +55,8 @@ _
         {module => 'HTTP::Parser::XS::PP', xs_module => 'HTTP::Parser::XS'},
         {module => 'Heap::Simple', xs_module => 'Heap::Simple::XS'},
         {module => 'Image::Info', xs_module => 'Image::Info::XS'},
-        {module => 'JSON::PP', pp_module=>'JSON', xs_module => 'JSON::XS'},
+        {module => 'JSON', pp_module=>'JSON::PP', xs_module => 'JSON::XS'},
+        {module => 'JSON::MaybeXS', xs_module => 'Cpanel::JSON::XS'},
         {module =>'Language::Befunge::Vector', xs_module => 'Language::Befunge::Vector::XS'},
         {module => 'Language::Befunge::Storage::Generic::Vec', xs_module => 'Language::Befunge::Storage::Generic::Vec::XS'},
         {module => 'List::BinarySearch', xs_module => 'List::BinarySearch::XS'},
@@ -69,9 +70,13 @@ _
         {module => 'Math::Utils', xs_module => 'Math::Utils::XS'},
         {module => 'MaxMind::DB::Reader', xs_module => 'MaxMind::DB::Reader::XS'},
         {module => 'Mojo::Base', xs_module => 'Mojo::Base::XS'},
+        {module => 'Moo', xs_module => 'Class::XSAccessor'},
+        # TODO: Mouse
         {module => 'Net::IP', xs_module => 'Net::IP::XS'},
         {module => 'Net::SNMP', xs_module => 'Net::SNMP::XS'},
         {module => 'Number::Closest', xs_module => 'Number::Closest::XS'},
+        {module => 'Object::Adhoc', xs_module => 'Class::XSAccessor'},
+        {module => 'Object::Accessor', xs_module => 'Object::Accessor::XS'},
         {module => 'Object::Tiny', xs_module => 'Object::Tiny::XS'},
         {module => 'Object::Tiny::RW', xs_module => 'Object::Tiny::RW::XS'},
         {module => 'PPI', xs_module => 'PPI::XS'},
@@ -80,6 +85,7 @@ _
         {module => 'Path::Hilbert', xs_module => 'Path::Hilbert::XS'},
         {module => 'PerlX::ArraySkip', xs_module => 'PerlX::ArraySkip::XS'},
         {module => 'PerlX::Maybe', xs_module => 'PerlX::Maybe::XS'},
+        {module => 'PPI', xs_module => 'PPI::XS'},
         {module => 'Protocol::Redis', xs_module => 'Protocol::Redis::XS'},
         {module => 'Readonly', xs_module => 'Readonly::XS'},
         {module => 'Ref::Util', xs_module => 'Ref::Util::XS'},
@@ -94,6 +100,7 @@ _
         # Text::Levenshtein & Text::Levenshtein::XS are different modules
         {module => 'Text::Levenshtein::Damerau', xs_module => 'Text::Levenshtein::Damerau::XS'},
         {module => 'Time::Format', xs_module => 'Time::Format_XS'},
+        {module => 'Type::Params', xs_module => 'Class::XSAccessor'},
         {module => 'Type::Tiny', xs_module => 'Type::Tiny::XS'},
         # Tree::Binary & Tree::Binary::XS are different modules
         {module => 'Tree::Object', xs_module => 'Tree::ObjectXS'},
@@ -110,7 +117,7 @@ _
 };
 
 1;
-# ABSTRACT: List of XS versions of Perl modules
+# ABSTRACT: List of Perl modules which have XS implementation or backend
 
 __END__
 
@@ -120,11 +127,11 @@ __END__
 
 =head1 NAME
 
-Acme::CPANModules::XSVersions - List of XS versions of Perl modules
+Acme::CPANModules::XSVersions - List of Perl modules which have XS implementation or backend
 
 =head1 VERSION
 
-This document describes version 0.003 of Acme::CPANModules::XSVersions (from Perl distribution Acme-CPANModules-XSVersions), released on 2022-03-18.
+This document describes version 0.004 of Acme::CPANModules::XSVersions (from Perl distribution Acme-CPANModules-XSVersions), released on 2023-09-05.
 
 =head1 SYNOPSIS
 
@@ -159,290 +166,474 @@ Additions much welcome.
 
 =over
 
-=item * L<Algorithm::Diff> - Compute `intelligent' differences between two files / lists
+=item L<Algorithm::Diff>
 
 Author: L<RJBS|https://metacpan.org/author/RJBS>
 
-=item * L<Algorithm::LUHN> - Calculate the Modulus 10 Double Add Double checksum
+XS module: L<Algorithm::Diff::XS>
+
+=item L<Algorithm::LUHN>
 
 Author: L<NEILB|https://metacpan.org/author/NEILB>
 
-=item * L<Algorithm::PageRank> - Calculate PageRank in Perl
+XS module: L<Algorithm::LUHN_XS>
+
+=item L<Algorithm::PageRank>
 
 Author: L<XERN|https://metacpan.org/author/XERN>
 
-=item * L<Algorithm::RectanglesContainingDot> - find rectangles containing a given dot
+XS module: L<Algorithm::PageRank::XS>
+
+=item L<Algorithm::RectanglesContainingDot>
 
 Author: L<SALVA|https://metacpan.org/author/SALVA>
 
-=item * L<Bytes::Random> - Perl extension to generate random bytes.
+XS module: L<Algorithm::RectanglesContainingDot_XS>
+
+=item L<Bytes::Random>
 
 Author: L<JOHND|https://metacpan.org/author/JOHND>
 
-=item * L<Class::Accessor::Fast> - Faster, but less expandable, accessors
+XS module: L<Bytes::Random::XS>
+
+=item L<Class::Accessor::Fast>
 
 Author: L<KASEI|https://metacpan.org/author/KASEI>
 
-=item * L<Class::C3> - A pragma to use the C3 method resolution order algorithm
+XS module: L<Class::Accessor::Fast::XS>
+
+=item L<Class::C3>
 
 Author: L<HAARG|https://metacpan.org/author/HAARG>
 
-=item * L<Class::Load> - A working (require "Class::Name") and more
+XS module: L<Class::C3::XS>
+
+=item L<Class::Load>
 
 Author: L<ETHER|https://metacpan.org/author/ETHER>
 
-=item * L<Convert::Bencode> - Functions for converting to/from bencoded strings
+XS module: L<Class::Load::XS>
+
+=item L<Convert::Bencode>
 
 Author: L<ORCLEV|https://metacpan.org/author/ORCLEV>
 
-=item * L<Crypt::Passwd> - Perl wrapper around the UFC Crypt
+XS module: L<Convert::Bencode_XS>
+
+=item L<Crypt::Passwd>
 
 Author: L<LUISMUNOZ|https://metacpan.org/author/LUISMUNOZ>
 
-=item * L<Crypt::TEA_PP> - Pure Perl Implementation of the Tiny Encryption Algorithm
+XS module: L<Crypt::Passwd::XS>
+
+=item L<Crypt::TEA_PP>
 
 Author: L<JAHIY|https://metacpan.org/author/JAHIY>
 
-=item * L<Crypt::XXTEA_PP> - Pure Perl Implementation of Corrected Block Tiny Encryption Algorithm
+XS module: L<Crypt::TEA_XS>
+
+=item L<Crypt::XXTEA_PP>
 
 Author: L<JAHIY|https://metacpan.org/author/JAHIY>
 
-=item * L<DDC::PP> - pure-perl DDC::XS clone: constants
+XS module: L<Crypt::XXTEA_XS>
+
+=item L<DDC::PP>
 
 Author: L<MOOCOW|https://metacpan.org/author/MOOCOW>
 
-=item * L<Crypt::Skip32> - 32-bit block cipher based on Skipjack
+XS module: L<DDC::XS>
+
+=item L<Crypt::Skip32>
 
 Author: L<ESH|https://metacpan.org/author/ESH>
 
-=item * L<Date::Calc>
+XS module: L<Crypt::Skip32::XS>
+
+=item L<Date::Calc>
 
 Author: L<STBEY|https://metacpan.org/author/STBEY>
 
-=item * L<Directory::Iterator> - Simple, efficient recursive directory listing
+XS module: L<Date::Calc::XS>
+
+PP module: L<Date::Calc::PP>
+
+=item L<Directory::Iterator>
 
 Author: L<SANBEG|https://metacpan.org/author/SANBEG>
 
-=item * L<Encode> - character encodings in Perl
+XS module: L<Directory::Iterator::XS>
+
+PP module: L<Directory::Iterator::PP>
+
+=item L<Encode>
 
 Author: L<DANKOGAI|https://metacpan.org/author/DANKOGAI>
 
-=item * L<Encoding::FixLatin> - takes mixed encoding input and produces UTF-8 output
+XS module: L<Encode::XS>
+
+=item L<Encoding::FixLatin>
 
 Author: L<GRANTM|https://metacpan.org/author/GRANTM>
 
-=item * L<File::MMagic> - Guess file type
+XS module: L<Encoding::FixLatin::XS>
+
+=item L<File::MMagic>
 
 Author: L<KNOK|https://metacpan.org/author/KNOK>
 
-=item * L<Geo::Coordinates::UTM> - Perl extension for Latitiude Longitude conversions.
+XS module: L<File::MMagic::XS>
+
+=item L<Geo::Coordinates::UTM>
 
 Author: L<GRAHAMC|https://metacpan.org/author/GRAHAMC>
 
-=item * L<Geo::Distance> - Calculate distances and closest locations. (DEPRECATED)
+XS module: L<Geo::Coordinates::UTM::XS>
+
+=item L<Geo::Distance>
 
 Author: L<BLUEFEET|https://metacpan.org/author/BLUEFEET>
 
-=item * L<Geo::Hash> - Encode / decode geohash.org locations.
+XS module: L<Geo::Distance::XS>
+
+=item L<Geo::Hash>
 
 Author: L<ANDYA|https://metacpan.org/author/ANDYA>
 
-=item * L<HTTP::Headers::Fast> - faster implementation of HTTP::Headers
+XS module: L<Geo::Hash::XS>
+
+=item L<HTTP::Headers::Fast>
 
 Author: L<TOKUHIROM|https://metacpan.org/author/TOKUHIROM>
 
-=item * L<HTTP::Parser::XS::PP>
+XS module: L<HTTP::Headers::Fast::XS>
+
+=item L<HTTP::Parser::XS::PP>
 
 Author: L<KAZUHO|https://metacpan.org/author/KAZUHO>
 
-=item * L<Heap::Simple> - Fast and easy to use classic heaps
+XS module: L<HTTP::Parser::XS>
+
+=item L<Heap::Simple>
 
 Author: L<THOSPEL|https://metacpan.org/author/THOSPEL>
 
-=item * L<Image::Info> - Extract meta information from image files
+XS module: L<Heap::Simple::XS>
+
+=item L<Image::Info>
 
 Author: L<SREZIC|https://metacpan.org/author/SREZIC>
 
-=item * L<JSON::PP> - JSON::XS compatible pure-Perl module.
+XS module: L<Image::Info::XS>
+
+=item L<JSON>
 
 Author: L<ISHIGAKI|https://metacpan.org/author/ISHIGAKI>
 
-=item * L<Language::Befunge::Vector> - an opaque, N-dimensional vector class
+XS module: L<JSON::XS>
+
+PP module: L<JSON::PP>
+
+=item L<JSON::MaybeXS>
+
+Author: L<ETHER|https://metacpan.org/author/ETHER>
+
+XS module: L<Cpanel::JSON::XS>
+
+=item L<Language::Befunge::Vector>
 
 Author: L<JQUELIN|https://metacpan.org/author/JQUELIN>
 
-=item * L<Language::Befunge::Storage::Generic::Vec> - a generic N-dimensional LaheySpace
+XS module: L<Language::Befunge::Vector::XS>
+
+=item L<Language::Befunge::Storage::Generic::Vec>
 
 Author: L<JQUELIN|https://metacpan.org/author/JQUELIN>
 
-=item * L<List::BinarySearch> - Binary Search within a sorted array.
+XS module: L<Language::Befunge::Storage::Generic::Vec::XS>
+
+=item L<List::BinarySearch>
 
 Author: L<DAVIDO|https://metacpan.org/author/DAVIDO>
 
-=item * L<List::Flatten> - Interpolate array references in a list
+XS module: L<List::BinarySearch::XS>
+
+=item L<List::Flatten>
 
 Author: L<OBRADOVIC|https://metacpan.org/author/OBRADOVIC>
 
-=item * L<List::MoreUtils> - Provide the stuff missing in List::Util
+XS module: L<List::Flatten::XS>
+
+=item L<List::MoreUtils>
 
 Author: L<REHSACK|https://metacpan.org/author/REHSACK>
 
-=item * L<List::SomeUtils> - Provide the stuff missing in List::Util
+XS module: L<List::MoreUtils::XS>
+
+=item L<List::SomeUtils>
 
 Author: L<DROLSKY|https://metacpan.org/author/DROLSKY>
 
-=item * L<List::Util> - A selection of general-utility list subroutines
+XS module: L<List::SomeUtils::XS>
+
+=item L<List::Util>
 
 Author: L<PEVANS|https://metacpan.org/author/PEVANS>
 
-=item * L<List::UtilsBy> - higher-order list utility functions
+XS module: L<List::Util::XS>
+
+=item L<List::UtilsBy>
 
 Author: L<PEVANS|https://metacpan.org/author/PEVANS>
 
-=item * L<Math::Derivative> - Numeric 1st and 2nd order differentiation
+XS module: L<List::UtilsBy::XS>
+
+=item L<Math::Derivative>
 
 Author: L<JGAMBLE|https://metacpan.org/author/JGAMBLE>
 
-=item * L<Math::Gauss> - Gaussian distribution function and its inverse
+XS module: L<Math::Derivative_XS>
+
+=item L<Math::Gauss>
 
 Author: L<JANERT|https://metacpan.org/author/JANERT>
 
-=item * L<Math::Utils> - Useful mathematical functions not in Perl.
+XS module: L<Math::Gauss::XS>
+
+=item L<Math::Utils>
 
 Author: L<JGAMBLE|https://metacpan.org/author/JGAMBLE>
 
-=item * L<MaxMind::DB::Reader> - Read MaxMind DB files and look up IP addresses
+XS module: L<Math::Utils::XS>
+
+=item L<MaxMind::DB::Reader>
 
 Author: L<MAXMIND|https://metacpan.org/author/MAXMIND>
 
-=item * L<Mojo::Base> - Minimal base class for Mojo projects
+XS module: L<MaxMind::DB::Reader::XS>
+
+=item L<Mojo::Base>
 
 Author: L<SRI|https://metacpan.org/author/SRI>
 
-=item * L<Net::IP> - Perl extension for manipulating IPv4/IPv6 addresses
+XS module: L<Mojo::Base::XS>
+
+=item L<Moo>
+
+Author: L<HAARG|https://metacpan.org/author/HAARG>
+
+XS module: L<Class::XSAccessor>
+
+=item L<Net::IP>
 
 Author: L<MANU|https://metacpan.org/author/MANU>
 
-=item * L<Net::SNMP> - Object oriented interface to SNMP 
+XS module: L<Net::IP::XS>
+
+=item L<Net::SNMP>
 
 Author: L<DTOWN|https://metacpan.org/author/DTOWN>
 
-=item * L<Number::Closest> - Find number(s) closest to a number in a list of numbers
+XS module: L<Net::SNMP::XS>
+
+=item L<Number::Closest>
 
 Author: L<ACCARDO|https://metacpan.org/author/ACCARDO>
 
-=item * L<Object::Tiny> - Class building as simple as it gets
+XS module: L<Number::Closest::XS>
 
-Author: L<ETHER|https://metacpan.org/author/ETHER>
-
-=item * L<Object::Tiny::RW> - Class building as simple as it gets (with rw accessors)
-
-Author: L<SCHWIGON|https://metacpan.org/author/SCHWIGON>
-
-=item * L<PPI> - Parse, Analyze and Manipulate Perl (without perl)
-
-Author: L<OALDERS|https://metacpan.org/author/OALDERS>
-
-=item * L<Package::Stash> - Routines for manipulating stashes
-
-Author: L<ETHER|https://metacpan.org/author/ETHER>
-
-=item * L<Params::Validate> - Validate method/function parameters
-
-Author: L<DROLSKY|https://metacpan.org/author/DROLSKY>
-
-=item * L<Path::Hilbert> - A no-frills converter between 1D and 2D spaces using the Hilbert curve
-
-Author: L<PWBENNETT|https://metacpan.org/author/PWBENNETT>
-
-=item * L<PerlX::ArraySkip> - sub { shift; @_ }
+=item L<Object::Adhoc>
 
 Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
 
-=item * L<PerlX::Maybe> - return a pair only if they are both defined
+XS module: L<Class::XSAccessor>
 
-Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
-
-=item * L<Protocol::Redis> - Redis protocol parser/encoder with asynchronous capabilities.
-
-Author: L<UNDEF|https://metacpan.org/author/UNDEF>
-
-=item * L<Readonly> - Facility for creating read-only scalars, arrays, hashes
-
-Author: L<SANKO|https://metacpan.org/author/SANKO>
-
-=item * L<Ref::Util> - Utility functions for checking references
-
-Author: L<ARC|https://metacpan.org/author/ARC>
-
-=item * L<Set::IntSpan::Fast> - Fast handling of sets containing integer spans.
-
-Author: L<ANDYA|https://metacpan.org/author/ANDYA>
-
-=item * L<Set::Product> - generates the cartesian product of a set of lists
-
-Author: L<GRAY|https://metacpan.org/author/GRAY>
-
-=item * L<SOAP::WSDL::Deserializer::XSD> - Deserializer SOAP messages into SOAP::WSDL::XSD::Typelib:: objects
-
-Author: L<SWALTERS|https://metacpan.org/author/SWALTERS>
-
-=item * L<Sort::Naturally>
+=item L<Object::Accessor>
 
 Author: L<BINGOS|https://metacpan.org/author/BINGOS>
 
-=item * L<String::Numeric> - Determine whether a string represents a numeric value
+XS module: L<Object::Accessor::XS>
+
+=item L<Object::Tiny>
+
+Author: L<ETHER|https://metacpan.org/author/ETHER>
+
+XS module: L<Object::Tiny::XS>
+
+=item L<Object::Tiny::RW>
+
+Author: L<SCHWIGON|https://metacpan.org/author/SCHWIGON>
+
+XS module: L<Object::Tiny::RW::XS>
+
+=item L<PPI>
+
+Author: L<OALDERS|https://metacpan.org/author/OALDERS>
+
+XS module: L<PPI::XS>
+
+=item L<Package::Stash>
+
+Author: L<ETHER|https://metacpan.org/author/ETHER>
+
+XS module: L<Package::Stash::XS>
+
+=item L<Params::Validate>
+
+Author: L<DROLSKY|https://metacpan.org/author/DROLSKY>
+
+XS module: L<Params::Validate::XS>
+
+=item L<Path::Hilbert>
+
+Author: L<PWBENNETT|https://metacpan.org/author/PWBENNETT>
+
+XS module: L<Path::Hilbert::XS>
+
+=item L<PerlX::ArraySkip>
+
+Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
+
+XS module: L<PerlX::ArraySkip::XS>
+
+=item L<PerlX::Maybe>
+
+Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
+
+XS module: L<PerlX::Maybe::XS>
+
+=item L<PPI>
+
+Author: L<OALDERS|https://metacpan.org/author/OALDERS>
+
+XS module: L<PPI::XS>
+
+=item L<Protocol::Redis>
+
+Author: L<UNDEF|https://metacpan.org/author/UNDEF>
+
+XS module: L<Protocol::Redis::XS>
+
+=item L<Readonly>
+
+Author: L<SANKO|https://metacpan.org/author/SANKO>
+
+XS module: L<Readonly::XS>
+
+=item L<Ref::Util>
+
+Author: L<ARC|https://metacpan.org/author/ARC>
+
+XS module: L<Ref::Util::XS>
+
+=item L<Set::IntSpan::Fast>
+
+Author: L<ANDYA|https://metacpan.org/author/ANDYA>
+
+XS module: L<Set::IntSpan::Fast::XS>
+
+=item L<Set::Product>
+
+Author: L<GRAY|https://metacpan.org/author/GRAY>
+
+XS module: L<Set::Product::XS>
+
+=item L<SOAP::WSDL::Deserializer::XSD>
+
+Author: L<SWALTERS|https://metacpan.org/author/SWALTERS>
+
+XS module: L<SOAP::WSDL::Deserializer::XSD_XS>
+
+=item L<Sort::Naturally>
+
+Author: L<BINGOS|https://metacpan.org/author/BINGOS>
+
+XS module: L<Sort::Naturally::XS>
+
+=item L<String::Numeric>
 
 Author: L<CHANSEN|https://metacpan.org/author/CHANSEN>
 
-=item * L<Template::Alloy>
+XS module: L<String::Numeric::XS>
+
+=item L<Template::Alloy>
 
 Author: L<RHANDOM|https://metacpan.org/author/RHANDOM>
 
-=item * L<Template::Stash> - Magical storage for template variables
+XS module: L<Template::Alloy::XS>
 
-Author: L<ATOOMIC|https://metacpan.org/author/ATOOMIC>
+=item L<Template::Stash>
 
-=item * L<Text::CSV> - comma-separated values manipulator (using XS or PurePerl)
+Author: L<ABW|https://metacpan.org/author/ABW>
+
+XS module: L<Template::Stash::XS>
+
+=item L<Text::CSV>
 
 Author: L<ISHIGAKI|https://metacpan.org/author/ISHIGAKI>
 
-=item * L<Text::Levenshtein::Damerau> - Damerau Levenshtein edit distance.
+XS module: L<Text::CSV_XS>
+
+=item L<Text::Levenshtein::Damerau>
 
 Author: L<UGEXE|https://metacpan.org/author/UGEXE>
 
-=item * L<Time::Format> - Easy-to-use date/time formatting.
+XS module: L<Text::Levenshtein::Damerau::XS>
+
+=item L<Time::Format>
 
 Author: L<ROODE|https://metacpan.org/author/ROODE>
 
-=item * L<Type::Tiny> - tiny, yet Moo(se)-compatible type constraint
+XS module: L<Time::Format_XS>
+
+=item L<Type::Params>
 
 Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
 
-=item * L<Tree::Object> - Generic tree objects
+XS module: L<Class::XSAccessor>
+
+=item L<Type::Tiny>
+
+Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
+
+XS module: L<Type::Tiny::XS>
+
+=item L<Tree::Object>
 
 Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>
 
-=item * L<URL::Encode>
+XS module: L<Tree::ObjectXS>
+
+=item L<URL::Encode>
 
 Author: L<CHANSEN|https://metacpan.org/author/CHANSEN>
 
-=item * L<Unix::Uptime::BSD> - BSD implementation of Unix::Uptime (for Darwin, DragonFly, and *BSD)
+XS module: L<URL::Encode::XS>
+
+=item L<Unix::Uptime::BSD>
 
 Author: L<PIOTO|https://metacpan.org/author/PIOTO>
 
-=item * L<XML::CompactTree> - builder of compact tree structures from XML documents
+XS module: L<Unix::Uptime::BSD::XS>
+
+=item L<XML::CompactTree>
 
 Author: L<PAJAS|https://metacpan.org/author/PAJAS>
 
-=item * L<YAML::PP> - YAML 1.2 processor
+XS module: L<XML::CompactTree::XS>
+
+=item L<YAML::PP>
 
 Author: L<TINITA|https://metacpan.org/author/TINITA>
 
-=item * L<match::simple> - simplified clone of smartmatch operator
+XS module: L<YAML::XS>
+
+=item L<match::simple>
 
 Author: L<TOBYINK|https://metacpan.org/author/TOBYINK>
 
+XS module: L<match::simple::XS>
+
 =back
 
 =head1 FAQ
@@ -494,6 +685,8 @@ L<Acme::CPANModules> - about the Acme::CPANModules namespace
 
 L<cpanmodules> - CLI tool to let you browse/view the lists
 
+L<Missing::XS>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
@@ -511,13 +704,14 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022, 2019 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
